#
# spec file for package dsda-doom
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dsda-doom
Version:        0.28.1
Release:        1.1
Summary:        DOOM source port with Hexen support and demo compatibility
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            https://github.com/kraflab/dsda-doom

#Changelog:     https://github.com/kraflab/dsda-doom/tree/master/patch_notes
#Announce:      https://www.doomworld.com/forum/topic/118074-dsda-doom-source-port-v0243/
Source:         https://github.com/kraflab/dsda-doom/archive/refs/tags/v%version.tar.gz
Patch1:         prboom-hbar-all.diff
Patch2:         prboom-hbar-gradient.diff
BuildRequires:  Mesa-devel
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  fluidsynth
BuildRequires:  fluidsynth-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libmad-devel
BuildRequires:  libpng-devel
BuildRequires:  libvorbis-devel
BuildRequires:  libzip-devel
BuildRequires:  libzip-tools
BuildRequires:  pcre-devel
BuildRequires:  portmidi-devel
BuildRequires:  portmidi-java
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_net)
BuildRequires:  pkgconfig(sdl2)
Suggests:       freedoom
Provides:       prboom

%description
DSDA-Doom is a source port derived from the PrBoom history line.
It features:

* Extra tooling for demo recording, with focus on speedrunning:
  record-rewind support
* Heretic and Hexen support
* MBFv21, UMAPINFO and DSDHacked specification support

%prep
%autosetup -p1

%build
pushd prboom2/
%cmake -DDOOMWADDIR="%_datadir/doom" -DDSDAPWADDIR="%_datadir/doom"
%cmake_build
popd

%install
pushd prboom2/
%cmake_install
b="%buildroot"
install -Dm0644 ICONS/dsda-doom.png "$b/%_datadir/icons/hicolor/apps/dsda-doom.png"
install -Dm0644 ICONS/dsda-doom.desktop "$b/%_datadir/applications/dsda-doom.desktop"
popd

%if 0%{?suse_version} && 0%{?suse_version} < 1550
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%_bindir/*
%_datadir/doom/
%_datadir/applications/*.desktop
%_datadir/icons/hicolor/apps/
%doc docs/*.md

%changelog
* Sun Aug 18 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.28.1
  * Fixed freelook menu crash, fixed numlock menu crash
* Thu Aug 15 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to release 0.28.0
  * Freelook aiming and projectile behavior has been rewritten
  * Added MAPINFO flags to support finite height explosion behavior
  * Added MAPINFO flags to support freelook
  * improvement on Tools, Console, and many Bug Fixes
    see https://github.com/kraflab/dsda-doom/blob/master/patch_notes/v0.28.md
* Sun Dec  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.27.5
  * DSDAHUD lumps are "merged" now so only redefined huds are changed
  * Fixed umapinfo bunny scroller crash
* Sat Nov 18 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.27.4
  * Added option to hide stat labels and totals
  * Fixed an overflow causing distant sprites (~8k map units) to
    not be rendered
* Sun Nov  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.27.3
  * New indexed light mode (software fidelity in OpenGL).
  * Improved controller support.
  * A new HUD system with new components.
  * New console commands and better usability.
  * UDMF support, MAPINFO support
  * ZIP file loading
  * Improved Heretic and Hexen suport
  * Upgraded to OPL3 emulation
  * You can switch back to OPL2 with config option mus_opl_opl3mode
- Delete prboom-nodatetime.diff, fluidsynth1.diff
- Add cmake-path-suffix.diff
- Note: If you updated from an old dsda-doom and use the same
  config file, your default complevel may have been reset to 0. If
  you run into an issue, check it out (suggested value is 21 /
  mbf21, if you don't know what to pick).
* Wed Mar 30 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.24.3
  * Improved automatic keyframe timeout behaviour
  * Fixed a crash caused by saving the game state after an
    intercept overrun
  * Added mouse stutter correction option (on by default)
- Add fluidsynth1.diff
* Fri Mar  4 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.24.2
  * Added another batch of cheats to the console
  * Removed process affinity hack
  * Added support for SNDFONT lump
  * Moved default soundfont into dsda-doom.wad
* Sat Feb 19 2022 Jan Engelhardt <jengelh@inai.de>
- Initial package (v0.24.1) for build.opensuse.org
- Reuse prboom-hbar-all.diff, prboom-hbar-gradient.diff,
  prboom-nodatetime.diff from prboom-plus package.
